JointLimit

Struct JointLimit 

pub struct JointLimit { /* private fields */ }
Optional descriptive joint limits.

Implementations

Source

impl JointLimit

pub fn new( minimum: Option<f64>, maximum: Option<f64>, ) -> Result<Self, JointLimitError>

Creates optional joint limits from finite numeric bounds.

Errors

Returns JointLimitError::NonFinite when a bound is not finite, or JointLimitError::Inverted when the minimum is greater than the maximum.

pub const fn unbounded() -> Self

Creates unbounded descriptive joint limits.

pub const fn minimum(self) -> Option<f64>

Returns the optional minimum limit.

pub const fn maximum(self) -> Option<f64>

Returns the optional maximum limit.